==> vfs-portlets-1.1-src.tar.gz: vfs-portlets-1.1/src/java/jp/sf/pal/vfs/beans/NewFilePageBean.java <==
/*
 * Copyright 2005-2006 The Portal Application Laboratory Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.sf.pal.vfs.beans;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.apache.commons.vfs.FileObject;
import org.apache.commons.vfs.FileSystemException;
import org.apache.commons.vfs.FileSystemManager;
import org.apache.commons.vfs.VFS;

import com.marevol.utils.faces.application.FacesMessageUtil;

public class NewFilePageBean
{
    /**
     * Logger for this class
     */
    private static final Log log = LogFactory.getLog(NewFilePageBean.class);

    private HeaderMenuSessionBean headerMenuSession;

    private String newFile;

    public String create()
    {
        try
        {
            FileSystemManager fsManager = VFS.getManager();
            FileObject newFileObject = fsManager
                    .resolveFile(getHeaderMenuSession().getUri() + "/"
                            + getNewFile());
            // TODO add confirmation
            // if (!newFileObject.exists())
            // {
            // TODO should catch exception to check if it's created
            newFileObject.createFile();

            // TODO I18N
            FacesMessageUtil
                    .addInfoMessage("Created new file: " + getNewFile());
            return getHeaderMenuSession().goToListViewPage();
            // }
        }
        catch (FileSystemException e)
        {
            // TODO I18N
            FacesMessageUtil.addInfoMessage("Failed to create the new file: "
                    + getNewFile(), e.toString());
            log.error("Failed to create the new file: " + getNewFile(), e);
        }
        return null;
    }

    /**
     * @return Returns the newFile.
     */
    public String getNewFile()
    {
        return newFile;
    }

    /**
     * @param newFile The newFile to set.
     */
    public void setNewFile(String newFile)
    {
        this.newFile = newFile;
    }

    /**
     * @return the headerMenuSession
     */
    public HeaderMenuSessionBean getHeaderMenuSession()
    {
        return headerMenuSession;
    }

    /**
     * @param headerMenuSession the headerMenuSession to set
     */
    public void setHeaderMenuSession(HeaderMenuSessionBean headerMenuSession)
    {
        this.headerMenuSession = headerMenuSession;
    }
}

==> vfs-portlets-1.2-src.tar.gz: vfs-portlets-1.2/src/java/jp/sf/pal/vfs/beans/NewFilePageBean.java <==
/*
 * Copyright 2005-2006 The Portal Application Laboratory Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.sf.pal.vfs.beans;

import java.util.Map;

import javax.faces.context.FacesContext;
import javax.faces.model.SelectItem;

import jp.sf.pal.vfs.VFSConstants;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class NewFilePageBean
{
    /**
     * Logger for this class
     */
    private static final Log log = LogFactory.getLog(NewFilePageBean.class);

    private HeaderMenuSessionBean headerMenuSession;

    private String newFile;

    private String type;

    public String next()
    {
        Map sessionMap = FacesContext.getCurrentInstance().getExternalContext()
                .getSessionMap();
        sessionMap.put(VFSConstants.NEW_FILE_CONTENT_FILE_NAME, getNewFile());
        sessionMap.put(VFSConstants.NEW_FILE_CONTENT_FILE_TYPE, getType());

        if (log.isDebugEnabled())
        {
            log.debug("next() newFile="+newFile);
            log.debug("next() type="+type);
        }

        return getHeaderMenuSession().goToNewFileContentPage();
    }

    public SelectItem[] getTypes()
    {
        // TODO I18N
        return new SelectItem[] { new SelectItem("TEXT", "Text"),
                new SelectItem("HTML", "Html") };
    }

    /**
     * @return Returns the newFile.
     */
    public String getNewFile()
    {
        return newFile;
    }

    /**
     * @param newFile The newFile to set.
     */
    public void setNewFile(String newFile)
    {
        this.newFile = newFile;
    }

    /**
     * @return the headerMenuSession
     */
    public HeaderMenuSessionBean getHeaderMenuSession()
    {
        return headerMenuSession;
    }

    /**
     * @param headerMenuSession the headerMenuSession to set
     */
    public void setHeaderMenuSession(HeaderMenuSessionBean headerMenuSession)
    {
        this.headerMenuSession = headerMenuSession;
    }

    /**
     * @return the type
     */
    public String getType()
    {
        return type;
    }

    /**
     * @param type the type to set
     */
    public void setType(String type)
    {
        this.type = type;
    }
}
